==> CDPKit-1.1.0.tar.gz: CDPKit-1.1.0/Libs/C++/Include/CDPL/ConfGen/StructureGenerationMode.hpp <==
/* 
 * StructureGenerationMode.hpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/**
 * \file
 * \brief Definition of constants in namespace CDPL::ConfGen::StructureGenerationMode.
 */

#ifndef CDPL_CONFGEN_STRUCTUREGENERATIONMODE_HPP
#define CDPL_CONFGEN_STRUCTUREGENERATIONMODE_HPP


namespace CDPL
{

    namespace ConfGen
    {

        /**
         * \brief Provides constants used to specify the employed structure generation method.
         */
        namespace StructureGenerationMode
        {

            const unsigned int AUTO              = 0;
            const unsigned int FRAGMENT          = 1;
            const unsigned int DISTANCE_GEOMETRY = 2;
        } // namespace StructureGenerationMode
    } // namespace ConfGen
} // namespace CDPL

#endif // CDPL_CONFGEN_STRUCTUREGENERATIONMODE_HPP

==> CDPKit-1.2.0.dev1.tar.gz: CDPKit-1.2.0.dev1/Libs/C++/Include/CDPL/ConfGen/StructureGenerationMode.hpp <==
/* 
 * StructureGenerationMode.hpp 
 *
 * This file is part of the Chemical Data Processing Toolkit
 *
 * Copyright (C) 2003 Thomas Seidel <thomas.seidel@univie.ac.at>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING. If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/**
 * \file
 * \brief Definition of constants in namespace CDPL::ConfGen::StructureGenerationMode.
 */

#ifndef CDPL_CONFGEN_STRUCTUREGENERATIONMODE_HPP
#define CDPL_CONFGEN_STRUCTUREGENERATIONMODE_HPP


namespace CDPL
{

    namespace ConfGen
    {

        /**
         * \brief Provides constants used to specify the employed structure generation method.
         */
        namespace StructureGenerationMode
        {

            constexpr unsigned int AUTO              = 0;
            constexpr unsigned int FRAGMENT          = 1;
            constexpr unsigned int DISTANCE_GEOMETRY = 2;
        } // namespace StructureGenerationMode
    } // namespace ConfGen
} // namespace CDPL

#endif // CDPL_CONFGEN_STRUCTUREGENERATIONMODE_HPP
